@@ -26,7 +26,7 @@ class DataAccessor:
     def rframe(self):
         return self.schema.rframe(self.storage)
 
-    def __init__(self, schema, datasource):
+    def __init__(self, schema, datasource, initdb=True):
         self.schema = schema
         self.storage = datasource
 
@@ -48,6 +48,9 @@ class DataAccessor:
             )
             method = makefun.create_function(signature, impl, func_name=name)
             setattr(self, name[1:], method)
+            
+        if initdb:
+            self.initdb()
 
     def _find(
         self, skip=None, limit=None, sort=None, **labels
@@ -58,7 +61,7 @@ class DataAccessor:
         query = self.schema.compile_query(datasource=self.storage, **labels)
         for doc in query.iter(limit=limit, skip=skip, sort=sort):
             try:
-                self.schema.validate(doc)
+                doc = self.schema(**doc).dict()
             except ValidationError:
                 continue
             yield doc
@@ -193,5 +196,5 @@ class DataAccessor:
             return res["success"]
         return res
 
-    def init_db(self):
-        self.schema.ensure_index(self.storage)
+    def initdb(self):
+        self.schema.initdb(self.storage)
