@@ -228,6 +228,8 @@ class PandasMultiQuery(PandasBaseQuery):
 
 @DatasourceInterface.register_interface(pd.DataFrame)
 class PandasInterface(DatasourceInterface):
+    source: pd.DataFrame
+
     @classmethod
     def from_url(cls, url: str, **kwargs):
         if url.endswith(".csv"):
@@ -289,6 +291,24 @@ class PandasInterface(DatasourceInterface):
             index = index[0]
         return self.source.drop(index=index, inplace=True)
 
+    def ensure_index(self, names, order=1):
+        index_names = self.source.index.names
+        
+        if all([name in index_names for name in names]):
+            return
+
+        if any([name in index_names for name in names]):
+            self.source.reset_index(inplace=True)
+
+        if len(names) == 1:
+            names = names[0]
+            
+        self.source.set_index(names, inplace=True)
+
+    def initdb(self, schema):
+        index_names = list(schema.get_index_fields())
+        self.ensure_index(index_names)
+
 
 @singledispatch
 def to_pandas(obj):
